| Title: | PEcAn Package for Integration of the GDAY Model |
|---|---|
| Description: | This module provides functions to link the GDAY model to PEcAn. |
| Authors: | Martin De Kauwe |
| Maintainer: | Martin De Kauwe <[email protected]> |
| License: | BSD_3_clause + file LICENSE |
| Version: | 1.7.5.9000 |
| Built: | 2026-06-05 14:46:40 UTC |
| Source: | https://github.com/PecanProject/pecan |
Function to convert NetCDF met files in PEcAn-CF format into GDAY met driver files. This function is an R wrapper to the python script "generate_forcing_data.py" in the inst/ folder. The python script supports arguments to generate sub-daily (30 min) weather data as well as soil temperature from 6 day running mean. These arguments are hard-coded in this function to generate daily GDAY files without soil temperature.
met2model.GDAY( in.path, in.prefix, outfolder, start_date, end_date, overwrite = FALSE, verbose = FALSE, ... )met2model.GDAY( in.path, in.prefix, outfolder, start_date, end_date, overwrite = FALSE, verbose = FALSE, ... )
in.path |
location on disk where inputs are stored |
in.prefix |
prefix of input and output files |
outfolder |
location on disk where outputs will be stored |
start_date |
the start date of the data to be downloaded (will only use the year part of the date) |
end_date |
the end date of the data to be downloaded (will only use the year part of the date) |
overwrite |
should existing files be overwritten |
verbose |
should the function be very verbose |
... |
additional arguments, currently ignored |
met2model for GDAY
generates GDAY formatted met file as a side affect, returns file metadata that will be inserted into database
Martin De Kauwe, Tony Gardella
Convert GDAY output to netCDF
model2netcdf.GDAY(outdir, sitelat, sitelon, start_date, end_date)model2netcdf.GDAY(outdir, sitelat, sitelon, start_date, end_date)
outdir |
Location of GDAY model output |
sitelat |
Latitude of the site |
sitelon |
Longitude of the site |
start_date |
Start time of the simulation |
end_date |
End time of the simulation |
Converts all output contained in a folder to netCDF.
Martin De Kauwe
Writes a config file for GDAY
write.config.GDAY(defaults, trait.values, settings, run.id)write.config.GDAY(defaults, trait.values, settings, run.id)
defaults |
list of defaults to process |
trait.values |
vector of samples for a given trait |
settings |
list of settings from pecan settings file |
run.id |
id of run |
Requires a pft xml object, a list of trait values for a single model run, and the name of the file to create
configuration file for GDAY for given run
Martin De Kauwe